Learn R Programming

collections (version 0.3.2)

collections-package: collections: High Performance Container Data Types

Description

Provides high performance container data types such as queues, stacks, deques, dicts and ordered dicts. Benchmarks <https://randy3k.github.io/collections/articles/benchmark.html> have shown that these containers are asymptotically more efficient than those offered by other packages.

Arguments

See Also

Useful links: